mysql.connection.Character_Set

Package mysql :: Module connection :: Class Character_Set |
[hide private]
[frames] | no frames]

# Class Character_Set

Information about a character set.

This object provides details about a character set returned from the Connection.get_current_character_set_info method.

Instance Methods | [hide private]
`` | __init__(...)
`` | __repr__(...)

Instance Variables | [hide private]
`` | collation_name The collation name.
`` | comment Comment about the character set.
`` | dir Character set directory.
`` | mb_max_len Multi-byte character maximum length.
`` | mb_min_len Multi-byte character minimum length.
`` | name The name of the character set.

Method Details | [hide private]

### __init__(...) (Constructor) |

### __repr__(...) (Representation operator) |

Instance Variable Details | [hide private]

### collation_name The collation name.

### comment Comment about the character set.

### dir Character set directory.

### mb_max_len Multi-byte character maximum length.

### mb_min_len Multi-byte character minimum length.

### name The name of the character set.